<?php
/**
rb-forms
Version: 1.0
By Upzilla.co Team

Contact: https://www.upzilla.co/rb-forms/
Created: 2022
Licensed under the GPLv2 license - http://opensource.org/licenses/gpl-2.0.php

Copyright (c) 2022, Upzilla.co All rights reserved.
Available only in https://www.upzilla.co
https://www.upzilla.co
 **/

namespace upz\rbforms;

if (!defined('WPINC')) {
    exit;
}

class Form
{

    protected $assetsUri;

    public function __construct()
    {
        $this->init();
        $this->hooks();
    }

    public function hooks()
    {
        add_shortcode('rbform', array($this, 'do_shortcode'));
        add_filter('the_content', array($this, 'form_content'));
        

        add_action('wp_head', array($this, 'add_form_to_frontend'));
    }

    public function add_form_to_frontend()
    {
        if (!$this->is_frontend()) {
            return;
        }
        $args = array(
            'numberposts' => 5,
            'post_type' => RB_FORMS_TYPE_POST_FORMS,
            'order' => 'ASC',
            'orderby' => 'title',
        );
        $forms = get_posts($args);

        if (!is_array($forms)) {
            return;
        }

        if (!count($forms)) {
            return;
        }

        $this->handle_forms($forms);
    }

    private function handle_forms($forms)
    {
        foreach ($forms as $form) {
            $id = $form->ID;
            if ($this->is_dialog_form($id)) {
                echo $this->getForm($id);
            }

        }
    }

    private function is_dialog_form($id)
    {
        if (!$id) {
            return false;
        }

        $options = get_post_meta($id, Config::KEY_OPTIONS, Config::DEFAULT_FORM_OPTIONS);
        return isset($options['useDialog']) && $options['useDialog'];
    }

    private function is_frontend()
    {
        if (is_admin()) {
            return false;
        }

        if (defined('DOING_AJAX') && DOING_AJAX) {
            return false;
        }

        if (defined('REST_REQUEST') && REST_REQUEST) {
            return false;
        }

        $prefix = rest_get_url_prefix();
        if (isset($_GET['rest_route']) && strpos(trim($_GET['rest_route'], '\\/'), $prefix, 0) === 0) {
            return false;
        }

        if (strpos(admin_url(), '/wp-admin/admin-ajax.php') !== false) {
            return false;
        }
        return true;
    }

    public function init()
    {
        $this->assetsUri = plugin_dir_url(__FILE__);
    }

    private static function get_id_from_attr($attr)
    {
        $id = 0;

        if (!isset($attr) || !count($attr)) {
            return '';
        }

        if (isset($attr['id']) && (int) $attr['id']) {
            $id = (int) $attr['id'];
        }

        if (!$id && isset($attr[0]) && (int) $attr[0]) {
            $id = (int) $attr[0];
        }
        return $id;
    }

    public function do_shortcode($attr)
    {
        $id = self::get_id_from_attr($attr);
        if (!$id) {
            return "RbForms :: attr[id]  is empty.";
        }
        return $this->getForm($id);
    }

    public function form_content($content)
    {
        global $post;
        if (post_password_required()) {
            return $content;
        }

        if (get_post_type() !== RB_FORMS_TYPE_POST_FORMS || !is_main_query()) {
            return $content;
        }

        return $content . do_shortcode("[rbform {$post->ID}]");
    }

    public function getForm($id)
    {
        wp_enqueue_script(Config::getAssetName('form'), $this->assetsUri . 'assets/main.js', array(), RB_FORMS_VERSION, true);

        return '<script>var rbforms_config_formid_' . $id . ' = ' . $this->get_options_json($id) . ';</script>'
            . '<div class="rb_contact_form" rbform_id="' . $id . '"></div>';
    }

    public function get_options_json($id)
    {
        $form_options = get_post_meta($id, 'rbforms_options', true);

        $privacy_policy_page_link = '#';

        if (function_exists('get_privacy_policy_url')) {
            $privacy_policy_page_link = get_privacy_policy_url();
        }

        if (!isset($form_options['fields']) || empty($form_options['fields']) || !is_array($form_options['fields'])) {
            echo "RbForm #" . $id . " - fields config read Error. Please configurate it before use.";
            return array();
        }

        $options = array(
            'restUrl' => rest_url(),
            'wp_rest' => wp_create_nonce('wp_rest'),
            'id' => $id,
            'privacy_link' => $privacy_policy_page_link,
            'terms_link' => $privacy_policy_page_link,
            'fields' => $form_options['fields'],
            'useDialog' => isset($form_options['useDialog']) && $form_options['useDialog'],

            'buttonWithText' => isset($form_options['buttonWithText']) && $form_options['buttonWithText'],
            'buttonLabel' => isset($form_options['buttonLabel']) ? $form_options['buttonLabel'] : '',
            'buttonIcon' => isset($form_options['buttonIcon']) ? $form_options['buttonIcon'] : 'EmailRounded',
            'buttonColor' => isset($form_options['buttonColor']) ? $form_options['buttonColor'] : 'success',
            'buttonSize' => isset($form_options['buttonSize']) ? $form_options['buttonSize'] : 'medium',
            'dialogTitle' => isset($form_options['dialogTitle']) ? $form_options['dialogTitle'] : 'Contact Us',
            'dialogDesc' => isset($form_options['dialogDesc']) ? $form_options['dialogDesc'] : '',
            'dialogButtonClose' => isset($form_options['dialogButtonClose']) ? $form_options['dialogButtonClose'] : 'Close',
            'dialogButtonSubmit' => isset($form_options['dialogButtonSubmit']) ? $form_options['dialogButtonSubmit'] : 'Submit',
        );

        return json_encode($options);
    }

    

}
new Form();
