<?php
/**
rb-forms
Version:
By Upzilla.co Team

Contact: https://www.upzilla.co/rb-forms/
Created: 2022
Licensed under the GPLv2 license - http://opensource.org/licenses/gpl-2.0.php

Copyright (c) 2022, Upzilla.co All rights reserved.
Available only in https://www.upzilla.co
https://www.upzilla.co
 **/

namespace upz\rbforms;

if (!defined('WPINC')) {
    exit;
}

class Listint
{
    public function __construct()
    {
        $this->init();
        $this->hooks();
    }

    public function init()
    {}

    public function hooks()
    {
        add_filter('post_row_actions', array($this, 'remove_quick_edit'), 10, 2);

        add_action('admin_head', array($this, 'addStyleToAdminSection'));

        // Register the columns.
        add_filter("manage_" . RB_FORMS_TYPE_POST_FORMS . "_posts_columns", array($this, "addColumns"));

        // Handle the value for each of the new columns.
        add_action("manage_" . RB_FORMS_TYPE_POST_FORMS . "_posts_custom_column", array($this, "renderColumns"), 10, 2);

        add_filter('manage_posts_columns', array($this, "reorderColumns"));

        add_filter('manage_edit-' . RB_FORMS_TYPE_POST_FORMS . '_sortable_columns', array($this, 'addSortableColumns'));

        // add_action('pre_get_posts', array($this, 'recordsOrderby'));

        //   add_filter('posts_orderby', array($this, 'edit_posts_orderby'));

        add_action('posts_clauses', array($this, 'orderByRecords'), 10, 2);

        //   add_filter( 'posts_join' , array($this,'custom_posts_join') );
        //  add_filter('posts_orderby', array($this,'edit_posts_orderby' ));
        //add_filter('posts_join_paged','custom_posts_join');
    }

    /**
     * remove Quick Edit
     *
     * @param [type] $actions
     * @param [type] $post
     * @return void
     */
    public function remove_quick_edit($actions, $post)
    {
        if ($post->post_type === RB_FORMS_TYPE_POST_FORMS) {
            //unset($actions['edit']);
            //unset($actions['trash']);
            //unset($actions['view']);

            if (isset($actions['inline hide-if-no-js'])) {
                unset($actions['inline hide-if-no-js']);
            }
        }
        return $actions;
    }

    public function custom_posts_join($join)
    {
        global $wpdb;

        $join .= " LEFT JOIN ".$wpdb->posts." records ON ".$wpdb->posts.".ID = records.post_parent AND records.post_type = '".RB_FORMS_TYPE_POST_FORMS."'";
        return $join;
    }

    public function listingOrdering($orderby_statement)
    {
        global $wpdb, $current_screen;

        if (!is_admin() || !$query->is_main_query()) {
            return $clauses;
        }

        if (isset($current_screen) && 'edit-' . RB_FORMS_TYPE_POST_FORMS == $current_screen->id) {

            //$orderby_statement = "count(records.*) DESC";
            //$order             = isset($query->query_vars) && isset($query->query_vars['order']) && strcasecmp($query->query_vars['order'], 'desc') == 0 ? 'DESC' : 'ASC';
            $orderby_statement = "ORDER BY (
                SELECT COUNT(*)
                FROM {$wpdb->posts} records
                WHERE records.post_type = '" . RB_FORMS_TYPE_POST_ROWS . "' AND records.post_parent = {$wpdb->posts}.ID  )
                 {$order}
                ";
            //   LEFT JOIN {$wpdb->post_meta} n_r ON  n_r.post_id=records.ID AND n_r.meta-key='_rbforms_read' AND n_r.meta_value = 0
        }
        return $orderby_statement;
    }

    public function orderByRecords($clauses, $query)
    {

        if (!is_admin() || !$query->is_main_query()) {
            return $clauses;
        }

        global $wpdb, $current_screen;

        if ($query->get('post_type') === RB_FORMS_TYPE_POST_FORMS && $query->get('orderby') === 'rbforms-records') {

            //  $clauses['join'] .= "LEFT OUTER JOIN {$wpdb -> posts} records ON {$wpdb->posts}.ID = records.post_parent AND records.post_type = 'rbforms_rows' ";
            //  $clauses['fields'] = $clauses['fields'] . ", count(records.*) as num_records ";

            $clauses['orderby'] = "  (
                select count(*)
                FROM wp_posts records
                WHERE wp_posts.ID = records.post_parent AND records.post_type = '" . RB_FORMS_TYPE_POST_ROWS . "'
            ) " . $query->get('order');

        }

        return $clauses;
    }

    // public function recordsOrderby($query)
    // {
    //     if (!is_admin() || !$query->is_main_query()) {
    //         return;
    //     }

    //     if ('rbforms-records' === $query->get('orderby')) {
    //         $query->set('orderby', 'meta_value');
    //         $query->set('meta_key', '_rbforms_read');
    //         $query->set('meta_type', 'numeric');
    //     }
    // }

    public function addSortableColumns($columns)
    {
        $columns['records'] = 'rbforms-records';
        return $columns;
    }

    public function addColumns($defaults)
    {
        $defaults['records']    = __('Records', 'forms-rb');
        return $defaults;
    }

    public function renderColumns($column_name, $form_id)
    {

        if ($column_name == 'records') {
            $stat = $this->geFormStat($form_id);
            if ($stat['unread']) {
                $format = '<span class="rbforms-unread">%1$d</span> / <span class="rbforms-count">%2$d</span>';
            } else {
                $format = '<span>%1$d</span> / <span class="rbforms-count">%2$d</span>';

            }
            echo sprintf($format, $stat['unread'], $stat['count']);
        }

    }

    public function geFormStat($form_id)
    {

        $args = array(
            'post_parent' => $form_id,
            //'posts_per_page' => 100,
            'nopaging'    => true,

            'order'       => 'DESC',
            'orderby'     => 'date',
            'post_status' => null,
            'post_type'   => RB_FORMS_TYPE_POST_ROWS,
        );
        $records = get_children($args);
        $count   = count($records);

        $args['meta_key']   = '_rbforms_read';
        $args['meta_value'] = 0;
        $unread_records     = get_children($args);
        $unread_count       = count($unread_records);

        return array('unread' => $unread_count, 'count' => $count);
    }

    public function reorderColumns($defaults)
    {
        $new     = array();
        $records = '';
        if (isset($defaults['records'])) {
            $records = $defaults['records']; // save the tags column
            unset($defaults['records']); // remove it from the columns list
        }

        foreach ($defaults as $key => $value) {
            if ($key == 'date') { // when we find the date column
                $new['records'] = $records; // put the tags column before it
            }
            $new[$key] = $value;
        }

        return $new;
    }

    public static function addStyleToAdminSection()
    {
        if(!is_admin()){
            return false;
        }
        global $pagenow;
        if($pagenow == 'edit.php' && isset($_GET['post_type']) && $_GET['post_type'] == RB_FORMS_TYPE_POST_FORMS){

        echo '<style>
        th#records.manage-column.column-records{
            max-width: 170px;
            width: 122px;
            text-align: center;
        }
        td.records.column-records{
            text-align: center;
        }
        .rbforms-unread, .rbforms-count{
            font-weight: bold;
        }
        .rbforms-unread{
            color: red;
        }
       </style>';
    }
    }

}

new Listint();
