<?php
/**
rb-forms
Version:
By Upzilla.co Team

Contact: https://www.upzilla.co/rb-forms/
Created: 2022
Licensed under the GPLv2 license - http://opensource.org/licenses/gpl-2.0.php

Copyright (c) 2022, Upzilla.co All rights reserved.
Available only in https://www.upzilla.co
https://www.upzilla.co
 **/

namespace upz\rbforms;

// Check if WordPress is loaded, and exit if not
if (!defined('WPINC')) {
    exit;
}

class Notification
{
    // The number of unread records. Set to -1 to indicate that the count has not been fetched yet.
    private $unreadRecords = -1;

    public function __construct()
    {
        $this->init();
        $this->hooks();
    }

    public function init()
    {}

    // Register hooks
    public function hooks()
    {
        add_action('admin_bar_menu', array($this, 'addMenuToAdminBar'), 50);
        add_action('admin_head', array($this, 'addStyleToAdminSection'));
        add_action('admin_menu', array($this, 'addNotificationCountToAdminMenu'));

        add_action('rbforms_cron_hook', array($this, 'cron_exec'));

        /* if (isset($_GET['rbforms_run_cron'])) {
            $this->cron_exec();
        } */
    }

    public function cron_exec()
    {
        $send_limit = 10;
        $args       = array(
            'posts_per_page' => $send_limit,
            'order'          => 'ASC',
            'orderby'        => 'date',
            'post_status'    => null,
            'post_type'      => RB_FORMS_TYPE_POST_ROWS,
            'meta_key'       => '_rbforms_sent',
            'meta_value'     => 0,
        );

        $records = get_posts($args);

        if (!count($records)) {
            return;
        }

        foreach ($records as $rec) {
            $this->sendEmailNotification($rec);
        }
    }

    public function sendEmailNotification($rec)
    {
        update_post_meta($rec->ID, '_rbforms_sent', 1, 0);

        $form_id = (int) $rec->post_parent;

        if (!$form_id) {
            return;
        }

        $options = get_post_meta($form_id, 'rbforms_options', true);

        $fields = array(
            'notification' => false,
            'mailText'     => '',
            'mailSubject'  => '',
            'mailTo'       => '',
        );

        if (!isset($options['notification']) || !$options['notification']) {
            return;
        }

        $fields['notification'] = true;

        if (isset($options['mailText'])) {
            $fields['mailText'] = $options['mailText'];
        }

        if (isset($options['mailSubject'])) {
            $fields['mailSubject'] = $options['mailSubject'];
        } else {
            $fields['mailSubject'] = __('Message from RB Forms', 'forms-rb');
        }

        if (isset($options['mailTo']) && $options['mailTo']) {
            $fields['mailTo'] = $options['mailTo'];
        } else {
            $fields['mailTo'] = get_option('admin_email');
        }

        $headers = array('Content-Type: text/html; charset=UTF-8');

        $fields['mailSubject'] = str_replace('{id}', $form_id, $fields['mailSubject']);
        $fields['mailSubject'] = str_replace('{title}', get_the_title($form_id), $fields['mailSubject']);

        $fields['mailText'] = str_replace('{id}', $form_id, $fields['mailText']);
        $fields['mailText'] = str_replace('{title}', get_the_title($form_id), $fields['mailText']);

        $data = "<br/>";
        $rows = get_post_meta($rec->ID, '_rbforms_rows', true);

        if (count($rows)) {
            foreach ($rows as $name => $value) {
                if($name=='agreement'){
                    continue;
                }
                $data .= '<p><strong>' . $name . ':</strong> ' . $value . "\n</p>";
            }
        }

        $fields['mailText'] = str_replace('{data}', $data, $fields['mailText']);

        $view_link = network_admin_url('post.php?action=edit&post=' . $form_id, 'https');
        $fields['mailText'] .= self::getEmailButton($view_link, __('View'));
        $fields['mailText'] = self::getEmailTemplate($fields['mailSubject'], $fields['mailText']);

        if (
            wp_mail(
                $fields['mailTo'],
                $fields['mailSubject'],
                $fields['mailText'],
                $headers
            )
        ) {
            update_post_meta($rec->ID, '_rbforms_sent', 2, 0);
        } else {
            update_post_meta($rec->ID, '_rbforms_sent', -1, 0);
        }
    }

    public function calcUnreadRecords()
    {
        $args = array(
            'nopaging'    => true,
            'order'       => 'DESC',
            'orderby'     => 'date',
            'post_status' => null,
            'post_type'   => RB_FORMS_TYPE_POST_ROWS,
            'meta_key'    => '_rbforms_read',
            'meta_value'  => 0,
        );
        $records             = get_posts($args);
        $this->unreadRecords = count($records);
    }

    public function getUnreadRecords()
    {
        if ($this->unreadRecords == -1) {
            $this->calcUnreadRecords();
        }
        return $this->unreadRecords;
    }

/**
 * To add an "Unread Records Count" label to the admin global menu item
 *
 * @return void
 */
    public function addNotificationCountToAdminMenu()
    {
        global $menu;
        $count = $this->getUnreadRecords();
        if (!$count) {
            return;
        }
        $menu_item = wp_list_filter(
            $menu,
            array(2 => 'edit.php?post_type=' . RB_FORMS_TYPE_POST_FORMS) // 2 is the position of an array item which contains URL, it will always be 2!
        );
        if (!empty($menu_item)) {
            $menu_item_position = key($menu_item); // get the array key (position) of the element
            $menu[$menu_item_position][0] .= ' <span class="awaiting-mod">' . $count . '</span>';
        }
    }

/**
 * Modify registered post type menu label - add unread records.
 *
 * @param string $post_type Registered post type name.
 * @param array $args Array of post type parameters.
 */
    public function addToDubMenuCountUnread($post_type, $args)
    {
        if (RB_FORMS_TYPE_POST_FORMS === $post_type) {
            global $wp_post_types;
            $count                     = $this->getUnreadRecords();
            $args->labels->all_items   = $args->labels->all_items . ($count ? ' <span class="awaiting-mod">' . $count . '</span>' : '');
            $wp_post_types[$post_type] = $args;
        }
    }

    public function addMenuToAdminBar($wp_admin_bar)
    {
        $unreadRecords = $this->getUnreadRecords();
        $menu_item     = '<span class="ab-icon" aria-hidden="true"></span> RB Forms';
        if ($unreadRecords) {
            $menu_item .= sprintf('<span class="rbforms-unread">%d</span>', $unreadRecords);
        }

        $args = array(
            'id'    => 'rb-forms-adminbar-button',
            'title' => $menu_item,
            'href'  => esc_url(admin_url('edit.php?post_type=' . RB_FORMS_TYPE_POST_FORMS . '&orderby=rbforms-records&order=desc')),
            'meta'  => array(
                'class' => 'custom-button-class',
                'title' => __('RB Forms'),
                'html'  => $unreadRecords ? '<span class="screen-reader-text rbforms-unread-text">' . $unreadRecords . ' records available</span>' : '',
            ),
        );
        $wp_admin_bar->add_node($args);
    }

    public static function addStyleToAdminSection()
    {
        echo '<style>
                #wpadminbar >  #wp-toolbar > #wp-admin-bar-root-default #wp-admin-bar-rb-forms-adminbar-button  .ab-icon:before {
                    content: "\f466";
                    top: 2px;
                }
                #wpadminbar >  #wp-toolbar > #wp-admin-bar-root-default #wp-admin-bar-rb-forms-adminbar-button  .rbforms-unread{
                    display: inline-block;
                    box-sizing: border-box;
                    margin: 1px 0 -1px 2px;
                    padding: 0 5px;
                    min-width: 18px;
                    height: 18px;
                    border-radius: 9px;
                    background-color: #d63638;
                    color: #fff;
                    font-size: 11px;
                    line-height: 1.6;
                    text-align: center;
                    z-index: 26;
                }
            </style>';
    }

    static public function getEmailButton($link, $text)
    {
        return '
            <table role="presentation" border="0" cellpadding="0" cellspacing="0" class="btn btn-primary">
                <tbody>
                    <tr>
                        <td align="left">
                            <table role="presentation" border="0" cellpadding="0" cellspacing="0">
                                <tbody>
                                    <tr>
                                        <td> <a href="' . $link . '" target="_blank">' . $text . '</a> </td>
                                    </tr>
                                </tbody>
                            </table>
                        </td>
                    </tr>
                </tbody>
            </table>';
    }

    static public function getEmailTemplate($title, $content)
    {
        return '
        <!doctype html>
<html>
  <head>
    <meta name="viewport" content="width=device-width, initial-scale=1.0"/>
    <meta http-equiv="Content-Type" content="text/html; charset=UTF-8" />
    <title>' . $title . '</title>
    <style>
      /* -------------------------------------
          GLOBAL RESETS
      ------------------------------------- */

      /*All the styling goes here*/

      img {
        border: none;
        -ms-interpolation-mode: bicubic;
        max-width: 100%;
      }

      body {
        background-color: #f6f6f6;
        font-family: sans-serif;
        -webkit-font-smoothing: antialiased;
        font-size: 14px;
        line-height: 1.4;
        margin: 0;
        padding: 0;
        -ms-text-size-adjust: 100%;
        -webkit-text-size-adjust: 100%;
      }

      table {
        border-collapse: separate;
        mso-table-lspace: 0pt;
        mso-table-rspace: 0pt;
        width: 100%; }
        table td {
          font-family: sans-serif;
          font-size: 14px;
          vertical-align: top;
      }

      /* -------------------------------------
          BODY & CONTAINER
      ------------------------------------- */

      .body {
        background-color: #f6f6f6;
        width: 100%;
      }

      /* Set a max-width, and make it display as block so it will automatically stretch to that width, but will also shrink down on a phone or something */
      .container {
        display: block;
        margin: 0 auto !important;
        /* makes it centered */
        max-width: 580px;
        padding: 10px;
        width: 580px;
      }

      /* This should also be a block element, so that it will fill 100% of the .container */
      .content {
        box-sizing: border-box;
        display: block;
        margin: 0 auto;
        max-width: 580px;
        padding: 10px;
      }

      /* -------------------------------------
          HEADER, FOOTER, MAIN
      ------------------------------------- */
      .main {
        background: #ffffff;
        border-radius: 3px;
        width: 100%;
      }

      .wrapper {
        box-sizing: border-box;
        padding: 20px;
      }

      .content-block {
        padding-bottom: 10px;
        padding-top: 10px;
      }

      .footer {
        clear: both;
        margin-top: 10px;
        text-align: center;
        width: 100%;
      }
        .footer td,
        .footer p,
        .footer span,
        .footer a {
          color: #999999;
          font-size: 12px;
          text-align: center;
      }

      /* -------------------------------------
          TYPOGRAPHY
      ------------------------------------- */
      h1,
      h2,
      h3,
      h4 {
        color: #000000;
        font-family: sans-serif;
        font-weight: 400;
        line-height: 1.4;
        margin: 0;
        margin-bottom: 30px;
      }

      h1 {
        font-size: 35px;
        font-weight: 300;
        text-align: center;
        text-transform: capitalize;
      }

      p,
      ul,
      ol {
        font-family: sans-serif;
        font-size: 14px;
        font-weight: normal;
        margin: 0;
        margin-bottom: 15px;
      }
        p li,
        ul li,
        ol li {
          list-style-position: inside;
          margin-left: 5px;
      }

      a {
        color: #3498db;
        text-decoration: underline;
      }

      /* -------------------------------------
          BUTTONS
      ------------------------------------- */
      .btn {
        box-sizing: border-box;
        width: 100%; }
        .btn > tbody > tr > td {
          padding-bottom: 15px; }
        .btn table {
          width: auto;
      }
        .btn table td {
          background-color: #ffffff;
          border-radius: 5px;
          text-align: center;
      }
        .btn a {
          background-color: #ffffff;
          border: solid 1px #3498db;
          border-radius: 5px;
          box-sizing: border-box;
          color: #3498db;
          cursor: pointer;
          display: inline-block;
          font-size: 14px;
          font-weight: bold;
          margin: 0;
          padding: 12px 25px;
          text-decoration: none;
          text-transform: capitalize;
      }

      .btn-primary table td {
        background-color: #3498db;
      }

      .btn-primary a {
        background-color: #3498db;
        border-color: #3498db;
        color: #ffffff;
      }

      /* -------------------------------------
          OTHER STYLES THAT MIGHT BE USEFUL
      ------------------------------------- */
      .last {
        margin-bottom: 0;
      }

      .first {
        margin-top: 0;
      }

      .align-center {
        text-align: center;
      }

      .align-right {
        text-align: right;
      }

      .align-left {
        text-align: left;
      }

      .clear {
        clear: both;
      }

      .mt0 {
        margin-top: 0;
      }

      .mb0 {
        margin-bottom: 0;
      }

      .preheader {
        color: transparent;
        display: none;
        height: 0;
        max-height: 0;
        max-width: 0;
        opacity: 0;
        overflow: hidden;
        mso-hide: all;
        visibility: hidden;
        width: 0;
      }

      .powered-by a {
        text-decoration: none;
      }

      hr {
        border: 0;
        border-bottom: 1px solid #f6f6f6;
        margin: 20px 0;
      }

      /* -------------------------------------
          RESPONSIVE AND MOBILE FRIENDLY STYLES
      ------------------------------------- */
      @media only screen and (max-width: 620px) {
        table.body h1 {
          font-size: 28px !important;
          margin-bottom: 10px !important;
        }
        table.body p,
        table.body ul,
        table.body ol,
        table.body td,
        table.body span,
        table.body a {
          font-size: 16px !important;
        }
        table.body .wrapper,
        table.body .article {
          padding: 10px !important;
        }
        table.body .content {
          padding: 0 !important;
        }
        table.body .container {
          padding: 0 !important;
          width: 100% !important;
        }
        table.body .main {
          border-left-width: 0 !important;
          border-radius: 0 !important;
          border-right-width: 0 !important;
        }
        table.body .btn table {
          width: 100% !important;
        }
        table.body .btn a {
          width: 100% !important;
        }
        table.body .img-responsive {
          height: auto !important;
          max-width: 100% !important;
          width: auto !important;
        }
      }

      /* -------------------------------------
          PRESERVE THESE STYLES IN THE HEAD
      ------------------------------------- */
      @media all {
        .ExternalClass {
          width: 100%;
        }
        .ExternalClass,
        .ExternalClass p,
        .ExternalClass span,
        .ExternalClass font,
        .ExternalClass td,
        .ExternalClass div {
          line-height: 100%;
        }
        .apple-link a {
          color: inherit !important;
          font-family: inherit !important;
          font-size: inherit !important;
          font-weight: inherit !important;
          line-height: inherit !important;
          text-decoration: none !important;
        }
        #MessageViewBody a {
          color: inherit;
          text-decoration: none;
          font-size: inherit;
          font-family: inherit;
          font-weight: inherit;
          line-height: inherit;
        }
        .btn-primary table td:hover {
          background-color: #34495e !important;
        }
        .btn-primary a:hover {
          background-color: #34495e !important;
          border-color: #34495e !important;
        }
      }

    </style>
  </head>
  <body>
    <span class="preheader">This is preheader text. Some clients will show this text as a preview.</span>
    <table role="presentation" border="0" cellpadding="0" cellspacing="0" class="body">
      <tr>
        <td>&nbsp;</td>
        <td class="container">
          <div class="content">

            <!-- START CENTERED WHITE CONTAINER -->
            <table role="presentation" class="main">

              <!-- START MAIN CONTENT AREA -->
              <tr>
                <td class="wrapper">
                  <table role="presentation" border="0" cellpadding="0" cellspacing="0">
                    <tr>
                      <td>
                        ' . $content . '
                      </td>
                    </tr>
                  </table>
                </td>
              </tr>

            <!-- END MAIN CONTENT AREA -->
            </table>
            <!-- END CENTERED WHITE CONTAINER -->

            <!-- START FOOTER -->
            <div class="footer">
              <table role="presentation" border="0" cellpadding="0" cellspacing="0">
                <tr>
                  <td class="content-block powered-by">
                    Powered by <a href="https://wordpress.org/plugins/forms-rb/">Rb Forms</a>.
                  </td>
                </tr>
              </table>
            </div>
            <!-- END FOOTER -->

          </div>
        </td>
        <td>&nbsp;</td>
      </tr>
    </table>
  </body>
</html> ';
    }

}

new Notification();
