<?php
/**
rb-forms
Version: 1.0
By Upzilla.co Team

Contact: https://www.upzilla.co/rb-forms/
Created: 2022
Licensed under the GPLv2 license - http://opensource.org/licenses/gpl-2.0.php

Copyright (c) 2022, Upzilla.co All rights reserved.
Available only in https://www.upzilla.co
https://www.upzilla.co
 **/

namespace upz\rbforms;

if (!defined('WPINC')) {
    exit;
}

class Records
{
    protected $assetsUri;

    public function __construct()
    {
        $this->init();
        $this->hooks();
    }

    public function hooks()
    {
        add_action('add_meta_boxes', array($this, 'addMetaBox'));
        add_action('save_post_' . RB_FORMS_TYPE_POST_FORMS, array($this, 'afterSaveForm'));
    }

    public function afterSaveForm($post_ID)
    {
        if (empty(get_post_meta($post_ID, Config::getOptionName('options'), array()))) {
            update_post_meta($post_ID, Config::getOptionName('options'), Config::DEFAULT_FORM_OPTIONS);
        }
    }

    public function init()
    {
        $this->assetsUri = plugin_dir_url(__FILE__);
    }

    public function addMetaBox()
    {
        add_meta_box(
            'rbforms-post-records-metabox',
            __('Records', 'forms-rb'),
            array($this, 'metaBoxRecords'),
            RB_FORMS_TYPE_POST_FORMS,
            'normal',
            'core'
        );

        add_meta_box(
            'rbforms-post-options-metabox',
            __('Options', 'forms-rb'),
            array($this, 'metaBoxOptions'),
            RB_FORMS_TYPE_POST_FORMS,
            'normal',
            'core'
        );
    }

    public function metaBoxOptions(\WP_Post $post)
    {
        if ($post->post_type != RB_FORMS_TYPE_POST_FORMS) {
            return;
        }

        /*
        $screen = get_current_screen();
        if ($screen && 'add' === $screen->action) {
        echo '<p>'.__('Please save the form first to get access to the configuration settings.', 'forms-rb').'</p>';
        return ;
        }
         */

        $post_id = $post->ID;

        if (!$post_id) {
            echo '<p>' . __('Please save the form first to get access to the configuration settings.', 'forms-rb') . '</p>';
            return;
        }

        wp_enqueue_script(Config::getAssetName('admin-options'), $this->assetsUri . 'options/main.js', array(), RB_FORMS_VERSION, true);

        $options = array(
            'restUrl' => rest_url(),
            'wp_rest' => wp_create_nonce('wp_rest'),
            'id' => $post_id,
        );

        $options_json = json_encode($options);

        echo '
<div id="rbforms_options" rbform_id="' . $post_id . '"></div>
<script> var rbforms_config_options_formid_' . $post_id . ' = ' . $options_json . '; </script>
        ';
    }

    public function metaBoxRecords(\WP_Post $post)
    {
        if ($post->post_type != RB_FORMS_TYPE_POST_FORMS) {
            return;
        }

        /*
        $screen = get_current_screen();
        if ($screen && 'add' === $screen->action) {
        echo '<p>'.__('Please save the form first to get access to the configuration settings.', 'forms-rb').'</p>';
        return ;
        } */

        $post_id = $post->ID;

        if (!$post_id) {
            echo '<p>' . __('Please save the form first to get access to the configuration settings.', 'forms-rb') . '</p>';
            return;
        }

        //wp_register_script(RB_FORMS_ASSETS_PREFIX . 'config', plugin_dir_url(__FILE__) . 'app/form/build/static/js/main.js', array(), RB_FORMS_VERSION, true);;

        wp_enqueue_script(Config::getAssetName('admin-records'), $this->assetsUri . 'lists/main.js', array(), RB_FORMS_VERSION, true);

        $options = array(
            'restUrl' => rest_url(),
            'wp_rest' => wp_create_nonce('wp_rest'),
            'id' => $post_id,
        );

        $options_json = json_encode($options);

        echo '
<div id="rbforms_records" rbform_id="' . $post_id . '"></div>
<script>var rbforms_config_formid_' . $post_id . ' = ' . $options_json . '; </script>
        ';
    }

}
new Records();
